Roboto has a dual nature. It has a mechanical skeleton and the forms are largely geometric. At the same time, the font features friendly and open curves. While some grotesks distort their letterforms to force a rigid rhythm, Roboto doesn’t compromise, allowing letters to be settled into their natural width. This makes for a more natural reading rhythm more commonly found in humanist and serif types.

This is the normal family, which can be used alongside the Roboto Condensed family and the Roboto Slab family.

Updated January 14 2015: Christian Robertson and the Material Design team unveiled the latest version of Roboto at Google I/O last year, and it is now available from Google Fonts. Existing websites using Roboto via Google Fonts will start using the latest version automatically. If you have installed the fonts on your computer, please download them again and re-install.